" Name:         Perchè il sole a Milano? Portofino? Dimmi la luna perchè?
" Description:  White(perchè il sole)/Black(la luna perchè?) background colorscheme.
" Author:       Maxim Kim <habamax@gmail.com>
" URL:          https://www.github.com/vim/colorschemes
" Last Change:  2025 Oct 22

" Generated by Colortemplate v3.0.0-beta10

hi clear
let g:colors_name = 'lunaperche'

let s:t_Co = has('gui_running') ? 16777216 : str2nr(&t_Co)
let s:tgc = has('termguicolors') && &termguicolors

hi! link CurSearch IncSearch
hi! link CursorLineFold FoldColumn
hi! link CursorLineSign FoldColumn
hi! link Float Number
hi! link Function Identifier
hi! link LineNrAbove LineNr
hi! link LineNrBelow LineNr
hi! link MessageWindow PMenu
hi! link Number Constant
hi! link PopupNotification Normal
hi! link PreInsert NonText
hi! link StatusLineTerm Statusline
hi! link StatusLineTermNC StatuslineNC
hi! link TabPanel Normal
hi! link TabPanelFill Normal
hi! link Terminal Normal
hi! link colortemplateKey Statement
hi! link csAccessModifier Statement
hi! link csAsyncModifier Statement
hi! link csClass Statement
hi! link csClassType Normal
hi! link csLogicSymbols Normal
hi! link csModifier Statement
hi! link csStorage Statement
hi! link csType Statement
hi! link diffFile PreProc
hi! link fugitiveHash Constant
hi! link fugitiveHeading Statement
hi! link fugitiveStagedHeading Statement
hi! link fugitiveStagedModifier PreProc
hi! link fugitiveSymbolicRef PreProc
hi! link fugitiveUnstagedHeading Statement
hi! link fugitiveUnstagedModifier PreProc
hi! link fugitiveUntrackedHeading Statement
hi! link helpHeader Title
hi! link helpHyperTextJump Underlined
hi! link helpVim Title
hi! link javaClassDecl Statement
hi! link javaDocParam PreProc
hi! link javaExternal Statement
hi! link javaScopeDecl Statement
hi! link javaScriptFunction Statement
hi! link javaScriptIdentifier Statement
hi! link javaStorageClass Statement
hi! link javaType Statement
hi! link markdownHeadingDelimiter Special
hi! link markdownUrl String
hi! link phpComparison Normal
hi! link phpDefine Statement
hi! link phpDocCustomTags phpDocTags
hi! link phpInclude Statement
hi! link phpMemberSelector Special
hi! link phpOperator Normal
hi! link phpParent Normal
hi! link phpSpecialFunction Normal
hi! link phpStorageClass Statement
hi! link phpStructure Statement
hi! link phpVarSelector Special
hi! link pythonInclude Statement
hi! link rstCodeBlock Normal
hi! link rstDelimiter Special
hi! link rstDirective PreProc
hi! link rstFieldName Constant
hi! link rstHyperlinkReference Special
hi! link rstInterpretedText Special
hi! link rstLiteralBlock rstCodeBlock
hi! link rstSectionDelimiter Statement
hi! link rubyDefine Statement
hi! link rubyMacro Statement
hi! link shCommandSub Normal
hi! link shDerefOp Special
hi! link shDerefPattern shQuote
hi! link shNoQuote Normal
hi! link shOperator Normal
hi! link shOption Normal
hi! link shQuote Constant
hi! link shSetOption Normal
hi! link shTestOpr Normal
hi! link sqlKeyword Statement
hi! link vimCommentString Comment
hi! link vimGroup Normal
hi! link vimOper Normal
hi! link vimOption Normal
hi! link vimParenSep Normal
hi! link vimSep Normal
hi! link vimVar Normal
hi! link xmlTagName Statement
hi! link yamlBlockMappingKey Statement

if &background == 'dark'
  let g:terminal_ansi_colors = ['#000000', '#af5f5f', '#5faf5f', '#af875f', '#5f87af', '#d787d7', '#5fafaf', '#c6c6c6', '#767676', '#ff5f5f', '#5fd75f', '#ffd787', '#5fafff', '#ff87ff', '#5fd7d7', '#ffffff']

  hi Normal guifg=#c6c6c6 guibg=#000000 guisp=NONE gui=NONE ctermfg=251 ctermbg=16 cterm=NONE term=NONE
  hi Added guifg=#5fd75f guibg=NONE guisp=NONE gui=NONE ctermfg=77 ctermbg=NONE cterm=NONE term=NONE
  hi Changed guifg=#5fafff guibg=NONE guisp=NONE gui=NONE ctermfg=75 ctermbg=NONE cterm=NONE term=NONE
  hi ColorColumn guifg=NONE guibg=#303030 guisp=NONE gui=NONE ctermfg=NONE ctermbg=236 cterm=NONE term=reverse
  hi Comment guifg=#5fafff guibg=NONE guisp=NONE gui=NONE ctermfg=75 ctermbg=NONE cterm=NONE term=bold
  hi Conceal guifg=#585858 guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=NONE
  hi Constant guifg=#ff87ff guibg=NONE guisp=NONE gui=NONE ctermfg=213 ctermbg=NONE cterm=NONE term=NONE
  hi CursorColumn guifg=NONE guibg=#262626 guisp=NONE gui=NONE ctermfg=NONE ctermbg=235 cterm=NONE term=NONE
  hi CursorLine guifg=NONE guibg=#262626 guisp=NONE gui=NONE ctermfg=NONE ctermbg=235 cterm=NONE term=underline
  hi CursorLineNr guifg=#ffffff guibg=NONE guisp=NONE gui=bold ctermfg=231 ctermbg=NONE cterm=bold term=bold
  hi DiffAdd guifg=NONE guibg=#273923 guisp=NONE gui=NONE ctermfg=251 ctermbg=22 cterm=NONE term=reverse
  hi DiffChange guifg=NONE guibg=#37352f guisp=NONE gui=NONE ctermfg=251 ctermbg=237 cterm=NONE term=NONE
  hi DiffDelete guifg=#767676 guibg=#2f1f1a guisp=NONE gui=NONE ctermfg=243 ctermbg=52 cterm=NONE term=reverse
  hi DiffText guifg=NONE guibg=#0f4f4f guisp=NONE gui=NONE ctermfg=251 ctermbg=23 cterm=NONE term=reverse
  hi Directory guifg=#5fafff guibg=NONE guisp=NONE gui=bold ctermfg=75 ctermbg=NONE cterm=bold term=NONE
  hi EndOfBuffer guifg=#585858 guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=NONE
  hi Error guifg=#ff5f5f guibg=#ffffff guisp=NONE gui=reverse ctermfg=203 ctermbg=231 cterm=reverse term=bold,reverse
  hi ErrorMsg guifg=#ff5f5f guibg=#ffffff guisp=NONE gui=reverse ctermfg=203 ctermbg=231 cterm=reverse term=bold,reverse
  hi FoldColumn guifg=#585858 guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=NONE
  hi Folded guifg=#767676 guibg=#303030 guisp=NONE gui=NONE ctermfg=243 ctermbg=236 cterm=NONE term=NONE
  hi Identifier guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=NONE
  hi Ignore guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=NONE
  hi IncSearch guifg=NONE guibg=#5f431f guisp=NONE gui=NONE ctermfg=16 ctermbg=77 cterm=NONE term=bold,reverse,underline
  hi LineNr guifg=#585858 guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=NONE
  hi MatchParen guifg=#ff00af guibg=NONE guisp=NONE gui=bold ctermfg=199 ctermbg=NONE cterm=bold term=bold,underline
  hi ModeMsg guifg=#ffd787 guibg=NONE guisp=NONE gui=reverse ctermfg=222 ctermbg=NONE cterm=reverse term=bold
  hi MoreMsg guifg=#5fd75f guibg=NONE guisp=NONE gui=NONE ctermfg=77 ctermbg=NONE cterm=NONE term=NONE
  hi NonText guifg=#585858 guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=NONE
  hi Pmenu guifg=NONE guibg=#303030 guisp=NONE gui=NONE ctermfg=NONE ctermbg=236 cterm=NONE term=reverse
  hi PmenuBorder guifg=#767676 guibg=#303030 guisp=NONE gui=NONE ctermfg=243 ctermbg=236 cterm=NONE term=NONE
  hi PmenuExtra guifg=#767676 guibg=#303030 guisp=NONE gui=NONE ctermfg=243 ctermbg=236 cterm=NONE term=NONE
  hi PmenuExtraSel guifg=#767676 guibg=#4e4e4e guisp=NONE gui=NONE ctermfg=243 ctermbg=239 cterm=NONE term=NONE
  hi PmenuKind guifg=#ff5f5f guibg=#303030 guisp=NONE gui=NONE ctermfg=203 ctermbg=236 cterm=NONE term=NONE
  hi PmenuKindSel guifg=#ff5f5f guibg=#4e4e4e guisp=NONE gui=NONE ctermfg=203 ctermbg=239 cterm=NONE term=NONE
  hi PmenuMatch guifg=#d787d7 guibg=#303030 guisp=NONE gui=NONE ctermfg=176 ctermbg=236 cterm=NONE term=NONE
  hi PmenuMatchSel guifg=#d787d7 guibg=#4e4e4e guisp=NONE gui=NONE ctermfg=176 ctermbg=239 cterm=NONE term=NONE
  hi PmenuSbar guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi PmenuSel guifg=NONE guibg=#4e4e4e guisp=NONE gui=NONE ctermfg=NONE ctermbg=239 cterm=NONE term=bold
  hi PmenuShadow guifg=#767676 guibg=#121212 guisp=NONE gui=NONE ctermfg=243 ctermbg=233 cterm=NONE term=NONE
  hi PmenuThumb guifg=NONE guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=NONE ctermbg=251 cterm=NONE term=NONE
  hi PreProc guifg=#5fd7d7 guibg=NONE guisp=NONE gui=NONE ctermfg=116 ctermbg=NONE cterm=NONE term=NONE
  hi Question guifg=#ff87ff guibg=NONE guisp=NONE gui=NONE ctermfg=213 ctermbg=NONE cterm=NONE term=standout
  hi QuickFixLine guifg=NONE guibg=#4f2f4f guisp=NONE gui=NONE ctermfg=251 ctermbg=53 cterm=NONE term=NONE
  hi Removed guifg=#ff5f5f guibg=NONE guisp=NONE gui=NONE ctermfg=203 ctermbg=NONE cterm=NONE term=NONE
  hi Search guifg=NONE guibg=#3a4a3a guisp=NONE gui=NONE ctermfg=16 ctermbg=222 cterm=NONE term=reverse
  hi SignColumn guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi Special guifg=#5fafaf guibg=NONE guisp=NONE gui=NONE ctermfg=73 ctermbg=NONE cterm=NONE term=NONE
  hi SpecialKey guifg=#585858 guibg=NONE guisp=NONE gui=NONE ctermfg=240 ctermbg=NONE cterm=NONE term=bold
  hi SpellBad guifg=NONE guibg=NONE guisp=#ff5f5f gui=undercurl ctermfg=203 ctermbg=NONE cterm=underline term=underline
  hi SpellCap guifg=NONE guibg=NONE guisp=#5fafaf gui=undercurl ctermfg=73 ctermbg=NONE cterm=underline term=underline
  hi SpellLocal guifg=NONE guibg=NONE guisp=#5fd75f gui=undercurl ctermfg=77 ctermbg=NONE cterm=underline term=underline
  hi SpellRare guifg=NONE guibg=NONE guisp=#ff87ff gui=undercurl ctermfg=213 ctermbg=NONE cterm=underline term=underline
  hi Statement guifg=#e4e4e4 guibg=NONE guisp=NONE gui=bold ctermfg=254 ctermbg=NONE cterm=bold term=NONE
  hi StatusLine guifg=#c6c6c6 guibg=#000000 guisp=NONE gui=bold,reverse ctermfg=251 ctermbg=16 cterm=bold,reverse term=bold,reverse
  hi StatusLineNC guifg=#767676 guibg=#000000 guisp=NONE gui=reverse ctermfg=243 ctermbg=16 cterm=reverse term=bold,underline
  hi String guifg=#ffd787 guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi TabLine guifg=#000000 guibg=#767676 guisp=NONE gui=NONE ctermfg=16 ctermbg=243 cterm=NONE term=bold,underline
  hi TabLineFill guifg=#000000 guibg=#767676 guisp=NONE gui=NONE ctermfg=16 ctermbg=243 cterm=NONE term=NONE
  hi TabLineSel guifg=#000000 guibg=#c6c6c6 guisp=NONE gui=bold ctermfg=16 ctermbg=251 cterm=bold term=bold,reverse
  hi Title guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=NONE
  hi TitleBar guifg=#ffffff guibg=#3c3c3c guisp=NONE gui=NONE ctermfg=231 ctermbg=237 cterm=NONE term=NONE
  hi TitleBarNC guifg=#767676 guibg=#2c2c2c guisp=NONE gui=NONE ctermfg=243 ctermbg=236 cterm=NONE term=NONE
  hi Todo guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold,reverse
  hi ToolbarButton guifg=#000000 guibg=#ffffff guisp=NONE gui=NONE ctermfg=16 ctermbg=231 cterm=NONE term=bold,reverse
  hi ToolbarLine guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi Type guifg=#5fd75f guibg=NONE guisp=NONE gui=NONE ctermfg=77 ctermbg=NONE cterm=NONE term=NONE
  hi Underlined guifg=NONE guibg=NONE guisp=NONE gui=underline ctermfg=NONE ctermbg=NONE cterm=underline term=underline
  hi VertSplit guifg=#767676 guibg=#767676 guisp=NONE gui=NONE ctermfg=243 ctermbg=243 cterm=NONE term=NONE
  hi Visual guifg=NONE guibg=#104070 guisp=NONE gui=NONE ctermfg=32 ctermbg=16 cterm=reverse term=reverse
  hi VisualNOS guifg=#000000 guibg=#5fafaf guisp=NONE gui=NONE ctermfg=16 ctermbg=73 cterm=NONE term=NONE
  hi WarningMsg guifg=#ff5f5f guibg=NONE guisp=NONE gui=NONE ctermfg=203 ctermbg=NONE cterm=NONE term=standout
  hi WildMenu guifg=#000000 guibg=#ffd787 guisp=NONE gui=bold ctermfg=16 ctermbg=222 cterm=bold term=bold
  hi debugBreakpoint guifg=#5fafaf guibg=NONE guisp=NONE gui=reverse ctermfg=73 ctermbg=NONE cterm=reverse term=reverse
  hi debugPC guifg=#5f87af guibg=NONE guisp=NONE gui=reverse ctermfg=67 ctermbg=NONE cterm=reverse term=reverse
  hi dirGroup guifg=#767676 guibg=NONE guisp=NONE gui=NONE ctermfg=243 ctermbg=NONE cterm=NONE term=NONE
  hi dirOwner guifg=#767676 guibg=NONE guisp=NONE gui=NONE ctermfg=243 ctermbg=NONE cterm=NONE term=NONE
  hi dirPermissionGroup guifg=#af875f guibg=NONE guisp=NONE gui=NONE ctermfg=137 ctermbg=NONE cterm=NONE term=NONE
  hi dirPermissionOther guifg=#5fafaf guibg=NONE guisp=NONE gui=NONE ctermfg=73 ctermbg=NONE cterm=NONE term=NONE
  hi dirPermissionUser guifg=#5faf5f guibg=NONE guisp=NONE gui=NONE ctermfg=71 ctermbg=NONE cterm=NONE term=NONE
  hi dirSize guifg=#ffd787 guibg=NONE guisp=NONE gui=NONE ctermfg=222 ctermbg=NONE cterm=NONE term=NONE
  hi dirSizeMod guifg=#d787d7 guibg=NONE guisp=NONE gui=NONE ctermfg=176 ctermbg=NONE cterm=NONE term=NONE
  hi dirTime guifg=#767676 guibg=NONE guisp=NONE gui=NONE ctermfg=243 ctermbg=NONE cterm=NONE term=NONE
  hi dirType guifg=#d787d7 guibg=NONE guisp=NONE gui=NONE ctermfg=176 ctermbg=NONE cterm=NONE term=NONE

  if s:tgc || s:t_Co >= 256
    if s:tgc
      hi IncSearch cterm=NONE
      hi QuickFixLine cterm=NONE
      hi Search cterm=NONE
      hi Visual cterm=NONE
    endif
    finish
  endif

  if s:t_Co >= 16
    hi Normal ctermfg=grey ctermbg=black cterm=NONE
    hi Added ctermfg=green ctermbg=NONE cterm=NONE
    hi Changed ctermfg=blue ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Comment ctermfg=blue ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=grey ctermbg=NONE cterm=NONE
    hi Constant ctermfg=magenta ctermbg=NONE cterm=NONE
    hi CursorColumn ctermfg=black ctermbg=yellow cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=white ctermbg=NONE cterm=bold
    hi DiffAdd ctermfg=darkgreen ctermbg=black cterm=reverse
    hi DiffChange ctermfg=darkyellow ctermbg=black cterm=reverse
    hi DiffDelete ctermfg=darkred ctermbg=black cterm=reverse
    hi DiffText ctermfg=darkcyan ctermbg=black cterm=reverse
    hi Directory ctermfg=blue ctermbg=NONE cterm=bold
    hi EndOfBuffer ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi Error ctermfg=red ctermbg=white cterm=reverse
    hi ErrorMsg ctermfg=red ctermbg=white cterm=reverse
    hi FoldColumn ctermfg=grey ctermbg=NONE cterm=NONE
    hi Folded ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Identifier ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Ignore ctermfg=NONE ctermbg=NONE cterm=NONE
    hi IncSearch ctermfg=black ctermbg=green cterm=NONE
    hi LineNr ctermfg=grey ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=NONE ctermbg=NONE cterm=bold,underline
    hi ModeMsg ctermfg=yellow ctermbg=NONE cterm=reverse
    hi MoreMsg ctermfg=green ctermbg=NONE cterm=NONE
    hi NonText ctermfg=grey ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=black ctermbg=grey cterm=NONE
    hi PmenuBorder ctermfg=NONE ctermbg=grey cterm=NONE
    hi PmenuExtra ctermfg=black ctermbg=grey cterm=NONE
    hi PmenuExtraSel ctermfg=black ctermbg=darkcyan cterm=NONE
    hi PmenuKind ctermfg=darkred ctermbg=grey cterm=NONE
    hi PmenuKindSel ctermfg=darkred ctermbg=darkcyan cterm=NONE
    hi PmenuMatch ctermfg=black ctermbg=grey cterm=bold
    hi PmenuMatchSel ctermfg=black ctermbg=darkcyan cterm=bold
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=black ctermbg=darkcyan cterm=NONE
    hi PmenuShadow ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuThumb ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PreProc ctermfg=cyan ctermbg=NONE cterm=NONE
    hi Question ctermfg=magenta ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=black ctermbg=magenta cterm=NONE
    hi Removed ctermfg=red ctermbg=NONE cterm=NONE
    hi Search ctermfg=black ctermbg=yellow cterm=NONE
    hi SignColumn ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Special ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=grey ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=red ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=darkcyan ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=green ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=magenta ctermbg=NONE cterm=underline
    hi Statement ctermfg=grey ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=grey ctermbg=black cterm=bold,reverse
    hi StatusLineNC ctermfg=darkgrey ctermbg=black cterm=reverse
    hi String ctermfg=yellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=black ctermbg=darkgrey cterm=NONE
    hi TabLineFill ctermfg=black ctermbg=darkgrey cterm=NONE
    hi TabLineSel ctermfg=black ctermbg=grey cterm=bold
    hi Title ctermfg=NONE ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=white ctermbg=black cterm=NONE
    hi TitleBarNC ctermfg=darkgrey ctermbg=black cterm=NONE
    hi Todo ctermfg=NONE ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=black ctermbg=white cterm=NONE
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=green ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=darkgrey ctermbg=darkgrey cterm=NONE
    hi Visual ctermfg=darkblue ctermbg=black cterm=reverse
    hi VisualNOS ctermfg=black ctermbg=darkcyan cterm=NONE
    hi WarningMsg ctermfg=red ctermbg=NONE cterm=NONE
    hi WildMenu ctermfg=black ctermbg=yellow cterm=bold
    hi debugBreakpoint ctermfg=darkcyan ctermbg=NONE cterm=reverse
    hi debugPC ctermfg=darkblue ctermbg=NONE cterm=reverse
    hi dirGroup ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirOwner ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirPermissionGroup ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi dirPermissionOther ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi dirPermissionUser ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi dirSize ctermfg=yellow ctermbg=NONE cterm=NONE
    hi dirSizeMod ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    hi dirTime ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirType ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 8
    hi Normal ctermfg=grey ctermbg=black cterm=NONE
    hi Added ctermfg=green ctermbg=NONE cterm=NONE
    hi Changed ctermfg=blue ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Comment ctermfg=darkblue ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Constant ctermfg=darkred ctermbg=NONE cterm=NONE
    hi CursorColumn ctermfg=black ctermbg=darkyellow cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=NONE ctermbg=NONE cterm=bold
    hi DiffAdd ctermfg=black ctermbg=darkgreen cterm=NONE
    hi DiffChange ctermfg=black ctermbg=darkyellow cterm=NONE
    hi DiffDelete ctermfg=black ctermbg=darkred cterm=NONE
    hi DiffText ctermfg=black ctermbg=darkmagenta cterm=NONE
    hi Directory ctermfg=darkblue ctermbg=NONE cterm=bold
    hi EndOfBuffer ctermfg=grey ctermbg=NONE cterm=NONE
    hi Error ctermfg=grey ctermbg=darkred cterm=NONE
    hi ErrorMsg ctermfg=grey ctermbg=darkred cterm=NONE
    hi FoldColumn ctermfg=grey ctermbg=NONE cterm=NONE
    hi Folded ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Identifier ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Ignore ctermfg=NONE ctermbg=NONE cterm=NONE
    hi IncSearch ctermfg=darkgreen ctermbg=black cterm=reverse
    hi LineNr ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=magenta ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=darkyellow ctermbg=black cterm=reverse
    hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi NonText ctermfg=grey ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuBorder ctermfg=darkgrey ctermbg=darkgrey cterm=NONE
    hi PmenuExtra ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuExtraSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuKind ctermfg=NONE ctermbg=NONE cterm=bold,reverse
    hi PmenuKindSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuMatch ctermfg=NONE ctermbg=darkred cterm=reverse
    hi PmenuMatchSel ctermfg=darkred ctermbg=NONE cterm=bold
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuShadow ctermfg=darkgrey ctermbg=black cterm=NONE
    hi PmenuThumb ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PreProc ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi Question ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=black ctermbg=darkmagenta cterm=NONE
    hi Removed ctermfg=red ctermbg=NONE cterm=NONE
    hi Search ctermfg=NONE ctermbg=NONE cterm=reverse
    hi SignColumn ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Special ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=grey ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=darkred ctermbg=NONE cterm=reverse,underline
    hi SpellCap ctermfg=darkcyan ctermbg=NONE cterm=reverse,underline
    hi SpellLocal ctermfg=darkgreen ctermbg=black cterm=reverse,underline
    hi SpellRare ctermfg=darkmagenta ctermbg=NONE cterm=reverse,underline
    hi Statement ctermfg=grey ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=grey ctermbg=black cterm=bold,reverse
    hi StatusLineNC ctermfg=black ctermbg=grey cterm=NONE
    hi String ctermfg=yellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=black ctermbg=grey cterm=NONE
    hi TabLineFill ctermfg=grey ctermbg=grey cterm=NONE
    hi TabLineSel ctermfg=grey ctermbg=black cterm=bold,reverse
    hi Title ctermfg=NONE ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=white ctermbg=black cterm=NONE
    hi TitleBarNC ctermfg=darkgrey ctermbg=black cterm=NONE
    hi Todo ctermfg=NONE ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=grey ctermbg=black cterm=bold,reverse
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=grey ctermbg=grey cterm=NONE
    hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
    hi VisualNOS ctermfg=black ctermbg=darkcyan cterm=NONE
    hi WarningMsg ctermfg=darkred ctermbg=NONE cterm=NONE
    hi WildMenu ctermfg=black ctermbg=darkyellow cterm=bold
    hi debugBreakpoint ctermfg=darkcyan ctermbg=NONE cterm=reverse
    hi debugPC ctermfg=darkblue ctermbg=NONE cterm=reverse
    hi dirGroup ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirOwner ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirPermissionGroup ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi dirPermissionOther ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi dirPermissionUser ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi dirSize ctermfg=yellow ctermbg=NONE cterm=NONE
    hi dirSizeMod ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    hi dirTime ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirType ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 0
    hi CurSearch term=reverse
    hi CursorIM term=NONE
    hi CursorLineFold term=underline
    hi CursorLineSign term=underline
    hi Float term=NONE
    hi Function term=NONE
    hi Number term=NONE
    hi StatusLineTerm term=bold,reverse
    hi StatusLineTermNC term=bold,underline
    hi Terminal term=NONE
    finish
  endif

  finish
endif

if &background == 'light'
  let g:terminal_ansi_colors = ['#000000', '#af0000', '#008700', '#af5f00', '#005fd7', '#af00af', '#005f5f', '#808080', '#767676', '#d70000', '#87d787', '#ffd787', '#0087d7', '#ff00ff', '#008787', '#ffffff']

  hi Normal guifg=#000000 guibg=#ffffff guisp=NONE gui=NONE ctermfg=16 ctermbg=231 cterm=NONE term=NONE
  hi Added guifg=#008700 guibg=NONE guisp=NONE gui=NONE ctermfg=28 ctermbg=NONE cterm=NONE term=NONE
  hi Changed guifg=#005fd7 guibg=NONE guisp=NONE gui=NONE ctermfg=26 ctermbg=NONE cterm=NONE term=NONE
  hi ColorColumn guifg=NONE guibg=#e4e4e4 guisp=NONE gui=NONE ctermfg=NONE ctermbg=254 cterm=NONE term=reverse
  hi Comment guifg=#005fd7 guibg=NONE guisp=NONE gui=NONE ctermfg=26 ctermbg=NONE cterm=NONE term=bold
  hi Conceal guifg=#9e9e9e guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi Constant guifg=#af00af guibg=NONE guisp=NONE gui=NONE ctermfg=127 ctermbg=NONE cterm=NONE term=NONE
  hi CursorColumn guifg=NONE guibg=#eeeeee guisp=NONE gui=NONE ctermfg=NONE ctermbg=255 cterm=NONE term=NONE
  hi CursorLine guifg=NONE guibg=#eeeeee guisp=NONE gui=NONE ctermfg=NONE ctermbg=255 cterm=NONE term=underline
  hi CursorLineNr guifg=#000000 guibg=NONE guisp=NONE gui=bold ctermfg=16 ctermbg=NONE cterm=bold term=bold
  hi DiffAdd guifg=NONE guibg=#c7d7c7 guisp=NONE gui=NONE ctermfg=16 ctermbg=108 cterm=NONE term=reverse
  hi DiffChange guifg=NONE guibg=#d7d7c7 guisp=NONE gui=NONE ctermfg=16 ctermbg=253 cterm=NONE term=NONE
  hi DiffDelete guifg=#767676 guibg=#d7b7b7 guisp=NONE gui=NONE ctermfg=16 ctermbg=131 cterm=NONE term=reverse
  hi DiffText guifg=NONE guibg=#a7cdcd guisp=NONE gui=NONE ctermfg=16 ctermbg=109 cterm=NONE term=reverse
  hi Directory guifg=#005fd7 guibg=NONE guisp=NONE gui=bold ctermfg=26 ctermbg=NONE cterm=bold term=NONE
  hi EndOfBuffer guifg=#9e9e9e guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi Error guifg=#ffffff guibg=#d70000 guisp=NONE gui=NONE ctermfg=231 ctermbg=160 cterm=NONE term=bold,reverse
  hi ErrorMsg guifg=#ffffff guibg=#d70000 guisp=NONE gui=NONE ctermfg=231 ctermbg=160 cterm=NONE term=bold,reverse
  hi FoldColumn guifg=#9e9e9e guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi Folded guifg=#767676 guibg=#e4e4e4 guisp=NONE gui=NONE ctermfg=243 ctermbg=254 cterm=NONE term=NONE
  hi Identifier guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=NONE
  hi Ignore guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=NONE
  hi IncSearch guifg=NONE guibg=#fff0cf guisp=NONE gui=NONE ctermfg=16 ctermbg=114 cterm=NONE term=bold,reverse,underline
  hi LineNr guifg=#9e9e9e guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi MatchParen guifg=#ff00af guibg=NONE guisp=NONE gui=bold ctermfg=199 ctermbg=NONE cterm=bold term=bold,underline
  hi ModeMsg guifg=#ffd787 guibg=#000000 guisp=NONE gui=reverse ctermfg=222 ctermbg=16 cterm=reverse term=bold
  hi MoreMsg guifg=#008700 guibg=NONE guisp=NONE gui=bold ctermfg=28 ctermbg=NONE cterm=bold term=NONE
  hi NonText guifg=#9e9e9e guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=NONE
  hi Pmenu guifg=NONE guibg=#e4e4e4 guisp=NONE gui=NONE ctermfg=NONE ctermbg=254 cterm=NONE term=reverse
  hi PmenuBorder guifg=#767676 guibg=#e4e4e4 guisp=NONE gui=NONE ctermfg=243 ctermbg=254 cterm=NONE term=NONE
  hi PmenuExtra guifg=#767676 guibg=#e4e4e4 guisp=NONE gui=NONE ctermfg=243 ctermbg=254 cterm=NONE term=NONE
  hi PmenuExtraSel guifg=#767676 guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=243 ctermbg=251 cterm=NONE term=NONE
  hi PmenuKind guifg=#af0000 guibg=#e4e4e4 guisp=NONE gui=NONE ctermfg=124 ctermbg=254 cterm=NONE term=NONE
  hi PmenuKindSel guifg=#af0000 guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=124 ctermbg=251 cterm=NONE term=NONE
  hi PmenuMatch guifg=#af00af guibg=#e4e4e4 guisp=NONE gui=NONE ctermfg=127 ctermbg=254 cterm=NONE term=NONE
  hi PmenuMatchSel guifg=#af00af guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=127 ctermbg=251 cterm=NONE term=NONE
  hi PmenuSbar guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi PmenuSel guifg=NONE guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=NONE ctermbg=251 cterm=NONE term=bold
  hi PmenuShadow guifg=#767676 guibg=#303030 guisp=NONE gui=NONE ctermfg=243 ctermbg=236 cterm=NONE term=NONE
  hi PmenuThumb guifg=NONE guibg=#767676 guisp=NONE gui=NONE ctermfg=NONE ctermbg=243 cterm=NONE term=NONE
  hi PreProc guifg=#005f5f guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi Question guifg=#af00af guibg=NONE guisp=NONE gui=bold ctermfg=127 ctermbg=NONE cterm=bold term=standout
  hi QuickFixLine guifg=NONE guibg=#e7cfe7 guisp=NONE gui=NONE ctermfg=16 ctermbg=182 cterm=NONE term=NONE
  hi Removed guifg=#d70000 guibg=NONE guisp=NONE gui=NONE ctermfg=160 ctermbg=NONE cterm=NONE term=NONE
  hi Search guifg=NONE guibg=#e7f3e7 guisp=NONE gui=NONE ctermfg=16 ctermbg=222 cterm=NONE term=reverse
  hi SignColumn guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi Special guifg=#008787 guibg=NONE guisp=NONE gui=NONE ctermfg=30 ctermbg=NONE cterm=NONE term=NONE
  hi SpecialKey guifg=#9e9e9e guibg=NONE guisp=NONE gui=NONE ctermfg=247 ctermbg=NONE cterm=NONE term=bold
  hi SpellBad guifg=NONE guibg=NONE guisp=#af0000 gui=undercurl ctermfg=124 ctermbg=NONE cterm=underline term=underline
  hi SpellCap guifg=NONE guibg=NONE guisp=#005f5f gui=undercurl ctermfg=23 ctermbg=NONE cterm=underline term=underline
  hi SpellLocal guifg=NONE guibg=NONE guisp=#008700 gui=undercurl ctermfg=28 ctermbg=NONE cterm=underline term=underline
  hi SpellRare guifg=NONE guibg=NONE guisp=#ff00ff gui=undercurl ctermfg=133 ctermbg=NONE cterm=underline term=underline
  hi Statement guifg=#000000 guibg=NONE guisp=NONE gui=bold ctermfg=16 ctermbg=NONE cterm=bold term=NONE
  hi StatusLine guifg=#ffffff guibg=#000000 guisp=NONE gui=bold ctermfg=231 ctermbg=16 cterm=bold term=bold,reverse
  hi StatusLineNC guifg=#ffffff guibg=#767676 guisp=NONE gui=NONE ctermfg=231 ctermbg=243 cterm=NONE term=bold,underline
  hi String guifg=#af5f00 guibg=NONE guisp=NONE gui=NONE ctermfg=130 ctermbg=NONE cterm=NONE term=NONE
  hi TabLine guifg=#000000 guibg=#bcbcbc guisp=NONE gui=NONE ctermfg=16 ctermbg=250 cterm=NONE term=bold,underline
  hi TabLineFill guifg=#bcbcbc guibg=#bcbcbc guisp=NONE gui=NONE ctermfg=250 ctermbg=250 cterm=NONE term=NONE
  hi TabLineSel guifg=#000000 guibg=#ffffff guisp=NONE gui=bold,reverse ctermfg=16 ctermbg=231 cterm=bold,reverse term=bold,reverse
  hi Title guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=NONE
  hi TitleBar guifg=#000000 guibg=#ececec guisp=NONE gui=NONE ctermfg=16 ctermbg=255 cterm=NONE term=NONE
  hi TitleBarNC guifg=#767676 guibg=#f5f5f5 guisp=NONE gui=NONE ctermfg=243 ctermbg=255 cterm=NONE term=NONE
  hi Todo guifg=NONE guibg=NONE guisp=NONE gui=bold ctermfg=NONE ctermbg=NONE cterm=bold term=bold,reverse
  hi ToolbarButton guifg=#ffffff guibg=#000000 guisp=NONE gui=NONE ctermfg=231 ctermbg=16 cterm=NONE term=bold,reverse
  hi ToolbarLine guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
  hi Type guifg=#008700 guibg=NONE guisp=NONE gui=NONE ctermfg=28 ctermbg=NONE cterm=NONE term=NONE
  hi Underlined guifg=NONE guibg=NONE guisp=NONE gui=underline ctermfg=NONE ctermbg=NONE cterm=underline term=underline
  hi VertSplit guifg=#767676 guibg=#767676 guisp=NONE gui=NONE ctermfg=243 ctermbg=243 cterm=NONE term=NONE
  hi Visual guifg=NONE guibg=#bfdfff guisp=NONE gui=NONE ctermfg=67 ctermbg=231 cterm=reverse term=reverse
  hi VisualNOS guifg=#ffffff guibg=#008787 guisp=NONE gui=NONE ctermfg=231 ctermbg=30 cterm=NONE term=NONE
  hi WarningMsg guifg=#d70000 guibg=NONE guisp=NONE gui=bold ctermfg=160 ctermbg=NONE cterm=bold term=standout
  hi WildMenu guifg=#000000 guibg=#ffd787 guisp=NONE gui=bold ctermfg=16 ctermbg=222 cterm=bold term=bold
  hi debugBreakpoint guifg=#005f5f guibg=NONE guisp=NONE gui=reverse ctermfg=23 ctermbg=NONE cterm=reverse term=reverse
  hi debugPC guifg=#005fd7 guibg=NONE guisp=NONE gui=reverse ctermfg=26 ctermbg=NONE cterm=reverse term=reverse
  hi dirFilterMenuBookmarkPath guifg=#626262 guibg=NONE guisp=NONE gui=NONE ctermfg=241 ctermbg=NONE cterm=NONE term=NONE
  hi dirFilterMenuHistoryPath guifg=#626262 guibg=NONE guisp=NONE gui=NONE ctermfg=241 ctermbg=NONE cterm=NONE term=NONE
  hi dirGroup guifg=#808080 guibg=NONE guisp=NONE gui=NONE ctermfg=244 ctermbg=NONE cterm=NONE term=NONE
  hi dirLink guifg=#008700 guibg=NONE guisp=NONE gui=bold ctermfg=28 ctermbg=NONE cterm=bold term=bold
  hi dirOwner guifg=#808080 guibg=NONE guisp=NONE gui=NONE ctermfg=244 ctermbg=NONE cterm=NONE term=NONE
  hi dirPermissionGroup guifg=#008700 guibg=NONE guisp=NONE gui=NONE ctermfg=28 ctermbg=NONE cterm=NONE term=NONE
  hi dirPermissionOther guifg=#af00af guibg=NONE guisp=NONE gui=NONE ctermfg=127 ctermbg=NONE cterm=NONE term=NONE
  hi dirPermissionUser guifg=#af5f00 guibg=NONE guisp=NONE gui=NONE ctermfg=130 ctermbg=NONE cterm=NONE term=NONE
  hi dirSize guifg=#af0000 guibg=NONE guisp=NONE gui=NONE ctermfg=124 ctermbg=NONE cterm=NONE term=NONE
  hi dirSizeMod guifg=#005f5f guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE
  hi dirTime guifg=#808080 guibg=NONE guisp=NONE gui=NONE ctermfg=244 ctermbg=NONE cterm=NONE term=NONE
  hi dirType guifg=#005f5f guibg=NONE guisp=NONE gui=NONE ctermfg=23 ctermbg=NONE cterm=NONE term=NONE

  if s:tgc || s:t_Co >= 256
    if s:tgc
      hi IncSearch cterm=NONE
      hi QuickFixLine cterm=NONE
      hi Search cterm=NONE
      hi Visual cterm=NONE
    endif
    finish
  endif

  if s:t_Co >= 16
    hi Normal ctermfg=black ctermbg=white cterm=NONE
    hi Added ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi Changed ctermfg=darkblue ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Comment ctermfg=darkblue ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi Constant ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    hi CursorColumn ctermfg=black ctermbg=yellow cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=black ctermbg=NONE cterm=bold
    hi DiffAdd ctermfg=black ctermbg=green cterm=NONE
    hi DiffChange ctermfg=black ctermbg=yellow cterm=NONE
    hi DiffDelete ctermfg=black ctermbg=red cterm=NONE
    hi DiffText ctermfg=black ctermbg=cyan cterm=NONE
    hi Directory ctermfg=darkblue ctermbg=NONE cterm=bold
    hi EndOfBuffer ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi Error ctermfg=white ctermbg=red cterm=NONE
    hi ErrorMsg ctermfg=white ctermbg=red cterm=NONE
    hi FoldColumn ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi Folded ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Identifier ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Ignore ctermfg=NONE ctermbg=NONE cterm=NONE
    hi IncSearch ctermfg=black ctermbg=green cterm=NONE
    hi LineNr ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=NONE ctermbg=NONE cterm=bold,underline
    hi ModeMsg ctermfg=yellow ctermbg=black cterm=reverse
    hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=bold
    hi NonText ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=black ctermbg=grey cterm=NONE
    hi PmenuBorder ctermfg=NONE ctermbg=grey cterm=NONE
    hi PmenuExtra ctermfg=black ctermbg=grey cterm=NONE
    hi PmenuExtraSel ctermfg=black ctermbg=darkcyan cterm=NONE
    hi PmenuKind ctermfg=darkred ctermbg=grey cterm=NONE
    hi PmenuKindSel ctermfg=darkred ctermbg=darkcyan cterm=NONE
    hi PmenuMatch ctermfg=darkmagenta ctermbg=grey cterm=NONE
    hi PmenuMatchSel ctermfg=darkmagenta ctermbg=darkcyan cterm=NONE
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=black ctermbg=darkcyan cterm=NONE
    hi PmenuShadow ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuThumb ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PreProc ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi Question ctermfg=darkmagenta ctermbg=NONE cterm=bold
    hi QuickFixLine ctermfg=black ctermbg=magenta cterm=NONE
    hi Removed ctermfg=red ctermbg=NONE cterm=NONE
    hi Search ctermfg=black ctermbg=yellow cterm=NONE
    hi SignColumn ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Special ctermfg=cyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=darkred ctermbg=NONE cterm=underline
    hi SpellCap ctermfg=darkcyan ctermbg=NONE cterm=underline
    hi SpellLocal ctermfg=darkgreen ctermbg=NONE cterm=underline
    hi SpellRare ctermfg=magenta ctermbg=NONE cterm=underline
    hi Statement ctermfg=black ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=white ctermbg=black cterm=bold
    hi StatusLineNC ctermfg=white ctermbg=darkgrey cterm=NONE
    hi String ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=black ctermbg=lightgrey cterm=NONE
    hi TabLineFill ctermfg=lightgrey ctermbg=lightgrey cterm=NONE
    hi TabLineSel ctermfg=black ctermbg=white cterm=bold,reverse
    hi Title ctermfg=NONE ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=black ctermbg=white cterm=NONE
    hi TitleBarNC ctermfg=darkgrey ctermbg=white cterm=NONE
    hi Todo ctermfg=NONE ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=white ctermbg=black cterm=NONE
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=darkgrey ctermbg=darkgrey cterm=NONE
    hi Visual ctermfg=white ctermbg=darkblue cterm=NONE
    hi VisualNOS ctermfg=black ctermbg=cyan cterm=NONE
    hi WarningMsg ctermfg=red ctermbg=NONE cterm=bold
    hi WildMenu ctermfg=black ctermbg=yellow cterm=bold
    hi debugBreakpoint ctermfg=darkcyan ctermbg=NONE cterm=reverse
    hi debugPC ctermfg=darkblue ctermbg=NONE cterm=reverse
    hi dirFilterMenuBookmarkPath ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirFilterMenuHistoryPath ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirGroup ctermfg=grey ctermbg=NONE cterm=NONE
    hi dirLink ctermfg=darkgreen ctermbg=NONE cterm=bold
    hi dirOwner ctermfg=grey ctermbg=NONE cterm=NONE
    hi dirPermissionGroup ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi dirPermissionOther ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    hi dirPermissionUser ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi dirSize ctermfg=darkred ctermbg=NONE cterm=NONE
    hi dirSizeMod ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi dirTime ctermfg=grey ctermbg=NONE cterm=NONE
    hi dirType ctermfg=darkcyan ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 8
    hi Normal ctermfg=black ctermbg=grey cterm=NONE
    hi Added ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi Changed ctermfg=darkblue ctermbg=NONE cterm=NONE
    hi ColorColumn ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Comment ctermfg=darkblue ctermbg=NONE cterm=NONE
    hi Conceal ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Constant ctermfg=darkred ctermbg=NONE cterm=NONE
    hi CursorColumn ctermfg=black ctermbg=darkyellow cterm=NONE
    hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
    hi CursorLineNr ctermfg=black ctermbg=NONE cterm=bold
    hi DiffAdd ctermfg=black ctermbg=darkgreen cterm=NONE
    hi DiffChange ctermfg=black ctermbg=darkyellow cterm=NONE
    hi DiffDelete ctermfg=black ctermbg=darkred cterm=NONE
    hi DiffText ctermfg=black ctermbg=darkmagenta cterm=NONE
    hi Directory ctermfg=darkblue ctermbg=NONE cterm=bold
    hi EndOfBuffer ctermfg=black ctermbg=NONE cterm=NONE
    hi Error ctermfg=grey ctermbg=darkred cterm=NONE
    hi ErrorMsg ctermfg=grey ctermbg=darkred cterm=NONE
    hi FoldColumn ctermfg=black ctermbg=NONE cterm=NONE
    hi Folded ctermfg=black ctermbg=darkyellow cterm=NONE
    hi Identifier ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Ignore ctermfg=NONE ctermbg=NONE cterm=NONE
    hi IncSearch ctermfg=black ctermbg=darkgreen cterm=reverse
    hi LineNr ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi MatchParen ctermfg=magenta ctermbg=NONE cterm=bold
    hi ModeMsg ctermfg=darkyellow ctermbg=black cterm=reverse
    hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi NonText ctermfg=black ctermbg=NONE cterm=NONE
    hi Pmenu ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuBorder ctermfg=darkgrey ctermbg=grey cterm=NONE
    hi PmenuExtra ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PmenuExtraSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuKind ctermfg=NONE ctermbg=NONE cterm=bold,reverse
    hi PmenuKindSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuMatch ctermfg=NONE ctermbg=darkred cterm=reverse
    hi PmenuMatchSel ctermfg=darkred ctermbg=NONE cterm=bold
    hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
    hi PmenuSel ctermfg=NONE ctermbg=NONE cterm=bold
    hi PmenuShadow ctermfg=darkgrey ctermbg=black cterm=NONE
    hi PmenuThumb ctermfg=NONE ctermbg=NONE cterm=reverse
    hi PreProc ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi Question ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    hi QuickFixLine ctermfg=grey ctermbg=darkmagenta cterm=bold
    hi Removed ctermfg=red ctermbg=NONE cterm=NONE
    hi Search ctermfg=black ctermbg=darkyellow cterm=reverse
    hi SignColumn ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Special ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi SpecialKey ctermfg=black ctermbg=NONE cterm=NONE
    hi SpellBad ctermfg=darkred ctermbg=NONE cterm=reverse,underline
    hi SpellCap ctermfg=darkcyan ctermbg=NONE cterm=reverse,underline
    hi SpellLocal ctermfg=darkgreen ctermbg=black cterm=reverse,underline
    hi SpellRare ctermfg=darkmagenta ctermbg=NONE cterm=reverse,underline
    hi Statement ctermfg=black ctermbg=NONE cterm=bold
    hi StatusLine ctermfg=grey ctermbg=black cterm=bold
    hi StatusLineNC ctermfg=grey ctermbg=darkgrey cterm=NONE
    hi String ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi TabLine ctermfg=grey ctermbg=black cterm=NONE
    hi TabLineFill ctermfg=black ctermbg=black cterm=NONE
    hi TabLineSel ctermfg=black ctermbg=grey cterm=bold,reverse
    hi Title ctermfg=black ctermbg=NONE cterm=bold
    hi TitleBar ctermfg=black ctermbg=white cterm=NONE
    hi TitleBarNC ctermfg=darkgrey ctermbg=white cterm=NONE
    hi Todo ctermfg=NONE ctermbg=NONE cterm=bold
    hi ToolbarButton ctermfg=grey ctermbg=black cterm=bold
    hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
    hi Type ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
    hi VertSplit ctermfg=black ctermbg=black cterm=NONE
    hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
    hi VisualNOS ctermfg=black ctermbg=darkcyan cterm=NONE
    hi WarningMsg ctermfg=darkred ctermbg=NONE cterm=NONE
    hi WildMenu ctermfg=black ctermbg=darkyellow cterm=bold
    hi debugBreakpoint ctermfg=darkcyan ctermbg=NONE cterm=reverse
    hi debugPC ctermfg=darkblue ctermbg=NONE cterm=reverse
    hi dirFilterMenuBookmarkPath ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirFilterMenuHistoryPath ctermfg=darkgrey ctermbg=NONE cterm=NONE
    hi dirGroup ctermfg=grey ctermbg=NONE cterm=NONE
    hi dirLink ctermfg=darkgreen ctermbg=NONE cterm=bold
    hi dirOwner ctermfg=grey ctermbg=NONE cterm=NONE
    hi dirPermissionGroup ctermfg=darkgreen ctermbg=NONE cterm=NONE
    hi dirPermissionOther ctermfg=darkmagenta ctermbg=NONE cterm=NONE
    hi dirPermissionUser ctermfg=darkyellow ctermbg=NONE cterm=NONE
    hi dirSize ctermfg=darkred ctermbg=NONE cterm=NONE
    hi dirSizeMod ctermfg=darkcyan ctermbg=NONE cterm=NONE
    hi dirTime ctermfg=grey ctermbg=NONE cterm=NONE
    hi dirType ctermfg=darkcyan ctermbg=NONE cterm=NONE
    finish
  endif

  if s:t_Co >= 0
    hi CurSearch term=reverse
    hi CursorIM term=NONE
    hi CursorLineFold term=underline
    hi CursorLineSign term=underline
    hi Float term=NONE
    hi Function term=NONE
    hi Number term=NONE
    hi StatusLineTerm term=bold,reverse
    hi StatusLineTermNC term=bold,underline
    hi Terminal term=NONE
    finish
  endif

endif

" vim: et ts=8 sw=2 sts=2
