" Name:         peachpuff
" Description:  This color scheme uses a peachpuff background (what you've expected when it's " called peachpuff?).
" Author:       Original author David Ne\v{c}as (Yeti) <yeti@physics.muni.cz>
" Maintainer:   Original maintainer David Ne\v{c}as (Yeti) <yeti@physics.muni.cz>
" URL:          https://github.com/vim/colorschemes
" License:      Same as Vim
" Last Change:  2025 Oct 14

" Generated by Colortemplate v3.0.0-beta10

set background=light

hi clear
let g:colors_name = 'peachpuff'

let s:t_Co = has('gui_running') ? 16777216 : str2nr(&t_Co)
let s:tgc = has('termguicolors') && &termguicolors

let g:terminal_ansi_colors = ['#ffdab9', '#a52a2a', '#c00058', '#cd00cd', '#008b8b', '#2e8b57', '#6a5acd', '#737373', '#406090', '#a52a2a', '#c00058', '#cd00cd', '#008b8b', '#2e8b57', '#6a5acd', '#000000']

hi! link CurSearch Search
hi! link CursorLineFold CursorLine
hi! link CursorLineSign CursorLine
hi! link Float Number
hi! link Function Identifier
hi! link LineNrAbove LineNr
hi! link LineNrBelow LineNr
hi! link MessageWindow Pmenu
hi! link Number Constant
hi! link PopupNotification Todo
hi! link TabPanel Normal
hi! link TabPanelFill EndOfBuffer
hi! link Terminal Normal

hi Normal guifg=#000000 guibg=#ffdab9 guisp=NONE gui=NONE ctermfg=16 ctermbg=223 cterm=NONE term=NONE
hi ColorColumn guifg=NONE guibg=#eeeeee guisp=NONE gui=NONE ctermfg=NONE ctermbg=255 cterm=NONE term=reverse
hi Comment guifg=#406090 guibg=NONE guisp=NONE gui=NONE ctermfg=25 ctermbg=NONE cterm=NONE term=bold
hi Conceal guifg=#737373 guibg=NONE guisp=NONE gui=NONE ctermfg=243 ctermbg=NONE cterm=NONE term=NONE
hi Constant guifg=#c00058 guibg=NONE guisp=NONE gui=NONE ctermfg=161 ctermbg=NONE cterm=NONE term=NONE
hi Cursor guifg=#ffdab9 guibg=#000000 guisp=NONE gui=NONE ctermfg=223 ctermbg=16 cterm=NONE term=reverse
hi CursorColumn guifg=NONE guibg=#f5c195 guisp=NONE gui=NONE ctermfg=NONE ctermbg=180 cterm=NONE term=NONE
hi CursorLine guifg=NONE guibg=#f5c195 guisp=NONE gui=NONE ctermfg=NONE ctermbg=180 cterm=NONE term=underline
hi CursorLineNr guifg=#cd0000 guibg=NONE guisp=NONE gui=bold ctermfg=160 ctermbg=NONE cterm=bold term=bold
hi DiffAdd guifg=#ffffff guibg=#5f875f guisp=NONE gui=NONE ctermfg=231 ctermbg=65 cterm=NONE term=reverse
hi DiffChange guifg=#ffffff guibg=#5f87af guisp=NONE gui=NONE ctermfg=231 ctermbg=67 cterm=NONE term=NONE
hi DiffDelete guifg=#ffffff guibg=#af5faf guisp=NONE gui=NONE ctermfg=231 ctermbg=133 cterm=NONE term=reverse
hi DiffText guifg=#000000 guibg=#c6c6c6 guisp=NONE gui=NONE ctermfg=16 ctermbg=251 cterm=NONE term=reverse
hi Directory guifg=#008b8b guibg=NONE guisp=NONE gui=bold ctermfg=30 ctermbg=NONE cterm=bold term=NONE
hi EndOfBuffer guifg=#737373 guibg=NONE guisp=NONE gui=NONE ctermfg=243 ctermbg=NONE cterm=NONE term=NONE
hi Error guifg=#ff0000 guibg=#ffffff guisp=NONE gui=bold,reverse ctermfg=196 ctermbg=231 cterm=bold,reverse term=bold,reverse
hi ErrorMsg guifg=#ff0000 guibg=#ffffff guisp=NONE gui=bold,reverse ctermfg=196 ctermbg=231 cterm=bold,reverse term=bold,reverse
hi FoldColumn guifg=#406090 guibg=NONE guisp=NONE gui=NONE ctermfg=25 ctermbg=NONE cterm=NONE term=NONE
hi Folded guifg=#000000 guibg=#e3c1a5 guisp=NONE gui=NONE ctermfg=16 ctermbg=252 cterm=NONE term=NONE
hi Identifier guifg=#008b8b guibg=NONE guisp=NONE gui=NONE ctermfg=30 ctermbg=NONE cterm=NONE term=NONE
hi Ignore guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=NONE
hi IncSearch guifg=#2e8b57 guibg=NONE guisp=NONE gui=reverse ctermfg=29 ctermbg=NONE cterm=reverse term=bold,reverse,underline
hi LineNr guifg=#cd0000 guibg=NONE guisp=NONE gui=NONE ctermfg=160 ctermbg=NONE cterm=NONE term=NONE
hi MatchParen guifg=#ffdab9 guibg=#6a5acd guisp=NONE gui=NONE ctermfg=223 ctermbg=62 cterm=NONE term=bold,underline
hi ModeMsg guifg=#000000 guibg=#ffdab9 guisp=NONE gui=bold ctermfg=16 ctermbg=223 cterm=bold term=bold
hi MoreMsg guifg=#2e8b57 guibg=#ffdab9 guisp=NONE gui=bold ctermfg=29 ctermbg=223 cterm=bold term=NONE
hi NonText guifg=#737373 guibg=NONE guisp=NONE gui=NONE ctermfg=243 ctermbg=NONE cterm=NONE term=NONE
hi Pmenu guifg=#000000 guibg=#ffaf87 guisp=NONE gui=NONE ctermfg=16 ctermbg=216 cterm=NONE term=reverse
hi PmenuBorder guifg=#5f5f5f guibg=#ffaf87 guisp=NONE gui=NONE ctermfg=59 ctermbg=216 cterm=NONE term=NONE
hi PmenuMatch guifg=#a52a2a guibg=#ffaf87 guisp=NONE gui=NONE ctermfg=124 ctermbg=216 cterm=NONE term=NONE
hi PmenuMatchSel guifg=#a52a2a guibg=#f5c195 guisp=NONE gui=bold ctermfg=124 ctermbg=180 cterm=bold term=bold
hi PmenuSbar guifg=NONE guibg=#ffdab9 guisp=NONE gui=NONE ctermfg=NONE ctermbg=223 cterm=NONE term=reverse
hi PmenuSel guifg=#000000 guibg=#f5c195 guisp=NONE gui=bold ctermfg=16 ctermbg=180 cterm=bold term=bold
hi PmenuShadow guifg=#737373 guibg=#303030 guisp=NONE gui=NONE ctermfg=243 ctermbg=236 cterm=NONE term=NONE
hi PmenuThumb guifg=NONE guibg=#737373 guisp=NONE gui=NONE ctermfg=NONE ctermbg=243 cterm=NONE term=NONE
hi PreProc guifg=#cd00cd guibg=NONE guisp=NONE gui=NONE ctermfg=164 ctermbg=NONE cterm=NONE term=NONE
hi Question guifg=#c00058 guibg=NONE guisp=NONE gui=bold ctermfg=161 ctermbg=NONE cterm=bold term=standout
hi QuickFixLine guifg=#000000 guibg=#ffaf87 guisp=NONE gui=NONE ctermfg=16 ctermbg=216 cterm=NONE term=NONE
hi Search guifg=#ffdab9 guibg=#cd00cd guisp=NONE gui=NONE ctermfg=223 ctermbg=164 cterm=NONE term=reverse
hi SignColumn guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
hi Special guifg=#6a5acd guibg=NONE guisp=NONE gui=NONE ctermfg=62 ctermbg=NONE cterm=NONE term=NONE
hi SpecialKey guifg=#737373 guibg=NONE guisp=NONE gui=NONE ctermfg=243 ctermbg=NONE cterm=NONE term=bold
hi SpellBad guifg=#ff0000 guibg=NONE guisp=#ff0000 gui=undercurl ctermfg=196 ctermbg=NONE cterm=underline term=underline
hi SpellCap guifg=#008b8b guibg=NONE guisp=#008b8b gui=undercurl ctermfg=30 ctermbg=NONE cterm=underline term=underline
hi SpellLocal guifg=#cd00cd guibg=NONE guisp=#cd00cd gui=undercurl ctermfg=164 ctermbg=NONE cterm=underline term=underline
hi SpellRare guifg=#6a5acd guibg=NONE guisp=#6a5acd gui=undercurl ctermfg=62 ctermbg=NONE cterm=underline term=underline
hi Statement guifg=#a52a2a guibg=NONE guisp=NONE gui=bold ctermfg=124 ctermbg=NONE cterm=bold term=NONE
hi StatusLine guifg=#ffffff guibg=#000000 guisp=NONE gui=bold ctermfg=231 ctermbg=16 cterm=bold term=bold,reverse
hi StatusLineNC guifg=#ffdab9 guibg=#737373 guisp=NONE gui=bold ctermfg=223 ctermbg=243 cterm=bold term=bold,underline
hi StatusLineTerm guifg=#ffffff guibg=#2e8b57 guisp=NONE gui=bold ctermfg=231 ctermbg=29 cterm=bold term=bold,reverse
hi StatusLineTermNC guifg=#ffdab9 guibg=#008b8b guisp=NONE gui=bold ctermfg=223 ctermbg=30 cterm=bold term=bold,underline
hi TabLine guifg=#ffdab9 guibg=#737373 guisp=NONE gui=underline ctermfg=223 ctermbg=243 cterm=underline term=bold,underline
hi TabLineFill guifg=NONE guibg=NONE guisp=NONE gui=reverse ctermfg=NONE ctermbg=NONE cterm=reverse term=NONE
hi TabLineSel guifg=#000000 guibg=#ffdab9 guisp=NONE gui=bold ctermfg=16 ctermbg=223 cterm=bold term=bold,reverse
hi Title guifg=#cd00cd guibg=NONE guisp=NONE gui=bold ctermfg=164 ctermbg=NONE cterm=bold term=NONE
hi TitleBar guifg=#000000 guibg=#dfba99 guisp=NONE gui=NONE ctermfg=16 ctermbg=255 cterm=NONE term=NONE
hi TitleBarNC guifg=#5f5f5f guibg=#efcaa9 guisp=NONE gui=NONE ctermfg=59 ctermbg=254 cterm=NONE term=NONE
hi Todo guifg=#6a5acd guibg=#ffff00 guisp=NONE gui=NONE ctermfg=62 ctermbg=226 cterm=NONE term=bold,reverse
hi ToolbarButton guifg=#ffdab9 guibg=#737373 guisp=NONE gui=bold ctermfg=223 ctermbg=243 cterm=bold term=bold,reverse
hi ToolbarLine guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
hi Type guifg=#2e8b57 guibg=NONE guisp=NONE gui=bold ctermfg=29 ctermbg=NONE cterm=bold term=NONE
hi Underlined guifg=#6a5acd guibg=NONE guisp=NONE gui=underline ctermfg=62 ctermbg=NONE cterm=underline term=underline
hi VertSplit guifg=#ffdab9 guibg=#737373 guisp=NONE gui=NONE ctermfg=223 ctermbg=243 cterm=NONE term=NONE
hi Visual guifg=#000000 guibg=#cccccc guisp=NONE gui=NONE ctermfg=16 ctermbg=252 cterm=NONE term=reverse
hi VisualNOS guifg=NONE guibg=#406090 guisp=NONE gui=NONE ctermfg=NONE ctermbg=25 cterm=NONE term=NONE
hi WarningMsg guifg=#cd00cd guibg=#ffdab9 guisp=NONE gui=bold ctermfg=164 ctermbg=223 cterm=bold term=standout
hi WildMenu guifg=#000000 guibg=#ffff00 guisp=NONE gui=bold ctermfg=16 ctermbg=226 cterm=bold term=bold
hi lCursor guifg=#000000 guibg=#c00058 guisp=NONE gui=NONE ctermfg=16 ctermbg=161 cterm=NONE term=NONE

if s:tgc || s:t_Co >= 256
  finish
endif

if s:t_Co >= 16
  hi Normal ctermfg=black ctermbg=white cterm=NONE
  hi ColorColumn ctermfg=NONE ctermbg=grey cterm=NONE
  hi Comment ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi Conceal ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi Constant ctermfg=darkred ctermbg=NONE cterm=NONE
  hi Cursor ctermfg=white ctermbg=black cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLineNr ctermfg=NONE ctermbg=NONE cterm=underline
  hi DiffAdd ctermfg=white ctermbg=darkgreen cterm=NONE
  hi DiffChange ctermfg=white ctermbg=blue cterm=NONE
  hi DiffDelete ctermfg=white ctermbg=magenta cterm=NONE
  hi DiffText ctermfg=black ctermbg=grey cterm=NONE
  hi Directory ctermfg=darkcyan ctermbg=NONE cterm=bold
  hi EndOfBuffer ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi Error ctermfg=darkred ctermbg=white cterm=bold,reverse
  hi ErrorMsg ctermfg=darkred ctermbg=white cterm=bold,reverse
  hi FoldColumn ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi Folded ctermfg=darkblue ctermbg=NONE cterm=NONE
  hi Identifier ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=NONE ctermbg=NONE cterm=NONE
  hi IncSearch ctermfg=darkgreen ctermbg=NONE cterm=reverse
  hi LineNr ctermfg=red ctermbg=NONE cterm=NONE
  hi MatchParen ctermfg=white ctermbg=darkblue cterm=NONE
  hi ModeMsg ctermfg=black ctermbg=white cterm=bold
  hi MoreMsg ctermfg=darkgreen ctermbg=white cterm=bold
  hi NonText ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi Pmenu ctermfg=black ctermbg=grey cterm=NONE
  hi PmenuBorder ctermfg=NONE ctermbg=grey cterm=NONE
  hi PmenuMatch ctermfg=black ctermbg=grey cterm=bold
  hi PmenuMatchSel ctermfg=black ctermbg=yellow cterm=bold
  hi PmenuSbar ctermfg=NONE ctermbg=white cterm=NONE
  hi PmenuSel ctermfg=black ctermbg=yellow cterm=NONE
  hi PmenuShadow ctermfg=NONE ctermbg=NONE cterm=NONE
  hi PmenuThumb ctermfg=NONE ctermbg=darkgrey cterm=NONE
  hi PreProc ctermfg=darkmagenta ctermbg=NONE cterm=NONE
  hi Question ctermfg=darkred ctermbg=NONE cterm=bold
  hi QuickFixLine ctermfg=black ctermbg=grey cterm=NONE
  hi Search ctermfg=white ctermbg=darkmagenta cterm=NONE
  hi SignColumn ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Special ctermfg=darkblue ctermbg=NONE cterm=NONE
  hi SpecialKey ctermfg=darkgrey ctermbg=NONE cterm=NONE
  hi SpellBad ctermfg=darkred ctermbg=NONE cterm=underline
  hi SpellCap ctermfg=darkcyan ctermbg=NONE cterm=underline
  hi SpellLocal ctermfg=darkmagenta ctermbg=NONE cterm=underline
  hi SpellRare ctermfg=darkblue ctermbg=NONE cterm=underline
  hi Statement ctermfg=darkred ctermbg=NONE cterm=bold
  hi StatusLine ctermfg=white ctermbg=black cterm=bold
  hi StatusLineNC ctermfg=white ctermbg=darkgrey cterm=bold
  hi StatusLineTerm ctermfg=white ctermbg=darkgreen cterm=bold
  hi StatusLineTermNC ctermfg=white ctermbg=darkcyan cterm=bold
  hi TabLine ctermfg=white ctermbg=darkgrey cterm=underline
  hi TabLineFill ctermfg=NONE ctermbg=NONE cterm=reverse
  hi TabLineSel ctermfg=black ctermbg=white cterm=bold
  hi Title ctermfg=darkmagenta ctermbg=NONE cterm=bold
  hi TitleBar ctermfg=black ctermbg=white cterm=NONE
  hi TitleBarNC ctermfg=darkgray ctermbg=white cterm=NONE
  hi Todo ctermfg=darkblue ctermbg=yellow cterm=NONE
  hi ToolbarButton ctermfg=white ctermbg=darkgrey cterm=bold
  hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Type ctermfg=darkgreen ctermbg=NONE cterm=bold
  hi Underlined ctermfg=darkblue ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=white ctermbg=darkgrey cterm=NONE
  hi Visual ctermfg=black ctermbg=grey cterm=NONE
  hi VisualNOS ctermfg=NONE ctermbg=darkgrey cterm=NONE
  hi WarningMsg ctermfg=darkmagenta ctermbg=white cterm=bold
  hi WildMenu ctermfg=black ctermbg=yellow cterm=bold
  hi lCursor ctermfg=black ctermbg=darkred cterm=NONE
  finish
endif

if s:t_Co >= 8
  hi Normal ctermfg=black ctermbg=gray cterm=NONE
  hi ColorColumn ctermfg=black ctermbg=darkred cterm=NONE
  hi Comment ctermfg=NONE ctermbg=NONE cterm=bold
  hi Conceal ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Constant ctermfg=darkred ctermbg=NONE cterm=NONE
  hi Cursor ctermfg=white ctermbg=black cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi CursorLineNr ctermfg=NONE ctermbg=NONE cterm=underline
  hi DiffAdd ctermfg=white ctermbg=darkgreen cterm=NONE
  hi DiffChange ctermfg=white ctermbg=darkblue cterm=NONE
  hi DiffDelete ctermfg=white ctermbg=darkmagenta cterm=NONE
  hi DiffText ctermfg=black ctermbg=grey cterm=NONE
  hi Directory ctermfg=darkcyan ctermbg=NONE cterm=bold
  hi EndOfBuffer ctermfg=darkblue ctermbg=NONE cterm=bold
  hi Error ctermfg=darkred ctermbg=gray cterm=bold,reverse
  hi ErrorMsg ctermfg=darkred ctermbg=gray cterm=bold,reverse
  hi FoldColumn ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Folded ctermfg=darkblue ctermbg=NONE cterm=NONE
  hi Identifier ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=NONE ctermbg=NONE cterm=NONE
  hi IncSearch ctermfg=darkgreen ctermbg=NONE cterm=reverse
  hi LineNr ctermfg=black ctermbg=NONE cterm=bold
  hi MatchParen ctermfg=gray ctermbg=darkblue cterm=NONE
  hi ModeMsg ctermfg=black ctermbg=NONE cterm=bold
  hi MoreMsg ctermfg=darkgreen ctermbg=NONE cterm=bold
  hi NonText ctermfg=darkblue ctermbg=NONE cterm=bold
  hi Pmenu ctermfg=black ctermbg=darkcyan cterm=NONE
  hi PmenuBorder ctermfg=darkgray ctermbg=grey cterm=NONE
  hi PmenuMatch ctermfg=black ctermbg=darkcyan cterm=bold
  hi PmenuMatchSel ctermfg=black ctermbg=darkyellow cterm=bold
  hi PmenuSbar ctermfg=NONE ctermbg=NONE cterm=NONE
  hi PmenuSel ctermfg=black ctermbg=darkyellow cterm=NONE
  hi PmenuShadow ctermfg=NONE ctermbg=NONE cterm=NONE
  hi PmenuThumb ctermfg=NONE ctermbg=darkgreen cterm=NONE
  hi PreProc ctermfg=darkmagenta ctermbg=NONE cterm=NONE
  hi Question ctermfg=darkred ctermbg=NONE cterm=bold
  hi QuickFixLine ctermfg=gray ctermbg=darkcyan cterm=NONE
  hi Search ctermfg=gray ctermbg=darkmagenta cterm=NONE
  hi SignColumn ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Special ctermfg=darkblue ctermbg=NONE cterm=NONE
  hi SpecialKey ctermfg=darkblue ctermbg=NONE cterm=bold
  hi SpellBad ctermfg=darkred ctermbg=NONE cterm=reverse
  hi SpellCap ctermfg=darkcyan ctermbg=NONE cterm=reverse
  hi SpellLocal ctermfg=darkmagenta ctermbg=NONE cterm=reverse
  hi SpellRare ctermfg=darkblue ctermbg=NONE cterm=reverse
  hi Statement ctermfg=darkred ctermbg=NONE cterm=bold
  hi StatusLine ctermfg=black ctermbg=gray cterm=bold,reverse
  hi StatusLineNC ctermfg=black ctermbg=gray cterm=reverse
  hi StatusLineTerm ctermfg=black ctermbg=gray cterm=bold,reverse
  hi StatusLineTermNC ctermfg=black ctermbg=gray cterm=reverse
  hi TabLine ctermfg=gray ctermbg=black cterm=NONE
  hi TabLineFill ctermfg=NONE ctermbg=NONE cterm=reverse
  hi TabLineSel ctermfg=black ctermbg=white cterm=NONE
  hi Title ctermfg=darkmagenta ctermbg=NONE cterm=bold
  hi TitleBar ctermfg=black ctermbg=white cterm=NONE
  hi TitleBarNC ctermfg=darkgray ctermbg=white cterm=NONE
  hi Todo ctermfg=darkblue ctermbg=darkyellow cterm=NONE
  hi ToolbarButton ctermfg=black ctermbg=gray cterm=bold,reverse
  hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Type ctermfg=darkgreen ctermbg=NONE cterm=NONE
  hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=black ctermbg=gray cterm=reverse
  hi Visual ctermfg=NONE ctermbg=NONE cterm=reverse
  hi VisualNOS ctermfg=NONE ctermbg=NONE cterm=underline
  hi WarningMsg ctermfg=darkmagenta ctermbg=NONE cterm=bold
  hi WildMenu ctermfg=black ctermbg=darkyellow cterm=NONE
  hi lCursor ctermfg=black ctermbg=darkred cterm=NONE
  finish
endif

if s:t_Co >= 0
  hi CurSearch term=reverse
  hi CursorIM term=NONE
  hi CursorLineFold term=underline
  hi CursorLineSign term=underline
  hi Float term=NONE
  hi Function term=NONE
  hi Number term=NONE
  hi Terminal term=NONE
  finish
endif

" vim: et ts=8 sw=2 sts=2
